#include <cstdio>
#include <iostream>
#include <string>
#include <vector>
#include <algorithm>
#include <cmath>


#define SQR(X) ((X)*(X))


using namespace std;


const long long MaxN = 100*1000;
const long long MaxAbsXYZ = 10*1000;


class Point {
	friend inline istream& operator >> (istream& in, Point& p) {
		in >> p.x >> p.y >> p.z;
		return in;
	}


private:
	long long x, y, z;


public:
	Point(long long _x = 0, long long _y = 0, long long _z = 0): x(_x), y(_y), z(_z) { };

	
	inline bool in_range(long long MaxAbsXYZ) const {
		return abs(x) <= MaxAbsXYZ && abs(y) <= MaxAbsXYZ && abs(z) <= MaxAbsXYZ;
	}

	
	Point operator += (const Point& p) {
		x += p.x;
		y += p.y;
		z += p.z;
		return *this;
	}

	
	Point operator - (const Point& p) const {
		return Point(x - p.x, y - p.y, z - p.z);
	}


	long long dist2(const Point& p) const {
		return SQR(x - p.x) + SQR(y - p.y) + SQR(z - p.z);
	}


	long long length2() const {
		return SQR(x) + SQR(y) + SQR(z);
	}

	long long operator * (const Point& p) const {
		return x*p.x + y*p.y + z*p.z;
	}
};


vector<Point> spacecraft;
Point sum;
int n;
long long s_prev, s_curr;


inline void my_assert(bool cond, const string& msg) {
	if (!cond) {
		cerr << "WRONG INPUT : ";
		cerr << msg << endl;		
		throw msg;
	}
}


int main() {
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
	cin >> n;
	my_assert(0 < n && n <= MaxN, "N is out of range");
	spacecraft.resize(n);
	for (vector<Point>::iterator it = spacecraft.begin(); it < spacecraft.end(); it++) {
		cin >> *it;
		my_assert(it->in_range(MaxAbsXYZ), "one of Points is out of range");
		sum += *it;
	}
	
	//Calculate penalty(0)
	s_prev = 0;
	for (vector<Point>::const_iterator it = spacecraft.begin(); it < spacecraft.end(); it++) {
		s_prev += spacecraft[0].dist2(*it);
	}
	cout << s_prev << endl;

	//Calculate penalty(i+1) using just penalty(i)
	for (int k = 1; k < n; k++) {
		Point d = spacecraft[k] - spacecraft[k-1];
		s_curr = s_prev + n * d.length2() + 2 * n * (d * spacecraft[k-1]) - 2 * (d * sum);
		cout << s_curr << endl;
		s_prev = s_curr;
	}
	fclose(stdin);
	fclose(stdout);
	return 0;
}
